package com.chinaitop.depot.business.controller;


import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.business.model.BusinessContractPayRecevice;
import com.chinaitop.depot.business.service.BusinessContractPayService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 粮库业务管理-合同收付款管理
* 
* <p>Description: </p>
* @author yaoyabin
* @date 2017年10月25日 下午5:33:42
 */
@RestController
@RequestMapping(value="/depot/business/contractPay")
public class BusinessContractPayController {
	
	@Resource
	private BusinessContractPayService contractPayService;
   
	
	/**
	 * 列表
	 * @param pageNum
	 * @param pageSize
	 * @return
	 */
	@RequestMapping(value="/getList",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
   	@ApiOperation(value="合同收付款列表", notes = "查询数据列表，支持分页")
   	@ApiImplicitParams({
   		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
   		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
   		@ApiImplicitParam(name = "contractNum", value = "合同编号", paramType = "query"),
   		@ApiImplicitParam(name = "payStatus", value = "收付款类型", paramType = "query"),
   		@ApiImplicitParam(name = "createTimeStart", value = "收付款日期", paramType = "query"),
   		@ApiImplicitParam(name = "createTimeEnd", value = "收付款日期", paramType = "query")
   	})
	public PageInfo<BusinessContractPayRecevice> getList(Integer pageNum, Integer pageSize,BusinessContractPayRecevice contractPayRecevice,String createTimeStart,String createTimeEnd) {
		List<BusinessContractPayRecevice> list = contractPayService.queryByExample(pageNum,pageSize,contractPayRecevice,createTimeStart,createTimeEnd);
		PageInfo<BusinessContractPayRecevice> pageInfo = new PageInfo<BusinessContractPayRecevice>(list);
		return pageInfo;
	}

	

	/**
	 * 保存
	 * @return
	 * @throws JsonParseException
	 * @throws JsonMappingException
	 * @throws IOException
	 */
	@RequestMapping(value="/contractPaySave", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="保存数据", notes = "保存")
    @SuppressWarnings("unchecked")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="contractJson", value="增加数据", paramType="form")
    })
	public Map<String, Object> save(HttpServletRequest request, String contractJson) throws JsonParseException, JsonMappingException, IOException {
		
        Map<String, Object> modelMap = new HashMap<String, Object>();
		try {
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            BusinessContractPayRecevice contract = (BusinessContractPayRecevice)mapper.readValue(contractJson, BusinessContractPayRecevice.class);
            if (contract.getId() == null) {
            	contractPayService.add(contract);
            } else {
            	
            }
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
		return modelMap;
	}
	
	
}
