package com.chinaitop.depot.utils;

import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.hssf.util.HSSFColor;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;
import org.springframework.web.multipart.MultipartFile;

import com.chinaitop.depot.business.model.BusinessDeliveryStorageNotice;
import com.chinaitop.depot.business.model.BusinessStoreWareDetail;
import com.chinaitop.depot.common.util.ExcelImportUtils;
import com.chinaitop.depot.feign.BasicEnumFeignService;
import com.chinaitop.depot.feign.OrgFeignService;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.*;
import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 
 * @author My Sunshine
 *
 */
@Service
public class NoticeImportServiceImpl {
	
	@Resource
    private BasicEnumFeignService basicEnumFeignService;
	@Resource
	private OrgFeignService orgFeignService;

	public Map<String, Object> temperData(String templatePath, HttpServletRequest request,
			BusinessDeliveryStorageNotice deliveryStorageNotice, List<BusinessStoreWareDetail> storeWareDetailList) throws Exception {
		// TODO Auto-generated method stub
		Map<String, Object> modelMap = new HashMap<String, Object>();
        // 服务器路径
        String rootPath = request.getSession().getServletContext().getRealPath("");
        //String rootPath = "D:\\eclipse_workspace\\work\\depot-yunnan\\depot-web-yunnan\\src\\main\\resources\\static\\app\\business";
        
        // 文件相对路径
        String relativePath = "/通知单详情导出模板.xlsx";
        //读取临时文件，并且返回错误信息
        String fileAllpath = rootPath+relativePath;
        //创建临时文件
        createTemp(templatePath,fileAllpath);
//        String fileAllpath = "E:\\粮食品种统计模板.xlsx";
        //获取File
        File tempFile = new File(fileAllpath);
        //获取第四行数据
        Workbook workbook = getWorkbook(tempFile,fileAllpath);
        //向临时模板写入数据
        setFileName(workbook,deliveryStorageNotice,storeWareDetailList);

        // 首先要创建一个原始Excel文件的输出流对象！
        FileOutputStream excelFileOutPutStream = new FileOutputStream(fileAllpath);
        // 将最新的 Excel 文件写入到文件输出流中，更新文件信息！
        workbook.write(excelFileOutPutStream);
        // 执行 flush 操作， 将缓存区内的信息更新到文件上
        excelFileOutPutStream.flush();
        // 使用后，及时关闭这个输出流对象， 好习惯，再强调一遍！
        excelFileOutPutStream.close();
        modelMap.put("fileAllpath",fileAllpath);
        return modelMap;
		
	}

	
	/**
    * 创建临时文件
    * @param oldPath 老的文件目录
    * @param newPath 新的文件目录
    * @throws Exception
    */
   public void createTemp(String oldPath, String newPath) throws Exception{
       File oldFile = new File(oldPath);
       File file = new File(newPath);
       FileInputStream in = new FileInputStream(oldFile);
       FileOutputStream out = new FileOutputStream(file);;

       byte[] buffer=new byte[2097152];
       int readByte = 0;
       while((readByte = in.read(buffer)) != -1){
           out.write(buffer, 0, readByte);
       }

       in.close();
       out.close();
   }

   //获取workbook
   private Workbook getWorkbook(File file ,String FileName){
       Workbook wb = null;
       try {
           InputStream is = new FileInputStream(file);
           if(ExcelImportUtils.isExcel2007(FileName)) {
               wb = new XSSFWorkbook(is);
           }
           else {
               wb = new HSSFWorkbook(is);
           }
       } catch (IOException e) {
           e.printStackTrace();
       }
       return wb;
   }
   


    //向临时模板写入数据
    private void setFileName(Workbook workbook,BusinessDeliveryStorageNotice deliveryStorageNotice, List<BusinessStoreWareDetail> storeWareDetailList){

        CellStyle cellStyle = workbook.createCellStyle();
        cellStyle.setAlignment(CellStyle.ALIGN_CENTER);
        //cellStyle.setBorderBottom(HSSFCellStyle.BORDER_THICK);
        //cellStyle.setBottomBorderColor(HSSFColor.RED.index);
        Sheet sheetX = workbook.getSheetAt(0);
        Row row = sheetX.getRow(2);
        
        //写数据
       // row.createCell(1, Cell.CELL_TYPE_STRING).setCellValue(deliveryStorageNotice.getBillNumber());//通知单编号
        //通知单编号
        Cell cell= row.createCell(1);
        cell.setCellValue(deliveryStorageNotice.getBillNumber());
        CellStyle style= workbook.createCellStyle();
        style.setBorderTop(CellStyle.BORDER_THIN);//上边框
        style.setBorderBottom(CellStyle.BORDER_THIN);//下边框
        cell.setCellStyle(style);
        //计划编号
        if(null != deliveryStorageNotice.getPlanNumber()){
        	Cell cell1= row.createCell(6);
            cell1.setCellValue(deliveryStorageNotice.getPlanNumber());
            CellStyle style1= workbook.createCellStyle();
            style1.setBorderTop(CellStyle.BORDER_THIN);//上边框
            style1.setBorderBottom(CellStyle.BORDER_THIN);//下边框
            cell1.setCellStyle(style1);
        }
      //合同编号
        if(null != deliveryStorageNotice.getContract()){
            Cell cell2= row.createCell(10);
            cell2.setCellValue(deliveryStorageNotice.getContract());
            CellStyle style2= workbook.createCellStyle();
            style2.setBorderTop(CellStyle.BORDER_THIN);//上边框
            style2.setBorderBottom(CellStyle.BORDER_THIN);//下边框
            cell2.setCellStyle(style2);
        }
        
        
        
        //row.createCell(6, Cell.CELL_TYPE_STRING).setCellValue(deliveryStorageNotice.getPlanNumber());//计划编号
        //row.createCell(10, Cell.CELL_TYPE_STRING).setCellValue(deliveryStorageNotice.getContract());//合同编号
        Row row1 = sheetX.getRow(3);
        //创建时间
        SimpleDateFormat sf = new SimpleDateFormat("yyyy-MM-dd hh:MM:ss");
        Cell cell3= row1.createCell(6);
        cell3.setCellValue(sf.format(deliveryStorageNotice.getCreateTime()));
        CellStyle style3= workbook.createCellStyle();
        style3.setBorderTop(CellStyle.BORDER_THIN);//上边框
        style3.setBorderBottom(CellStyle.BORDER_THIN);//下边框
        style3.setBorderLeft(CellStyle.BORDER_THIN);//左边框
        cell3.setCellStyle(style3);
        row1.createCell(1, Cell.CELL_TYPE_STRING).setCellValue(deliveryStorageNotice.getCreater());//申请人
        
       // row1.createCell(6, Cell.CELL_TYPE_STRING).setCellValue(sf.format(deliveryStorageNotice.getCreateTime()));//创建时间
        //根据字典id 获取名称
        String  ysfs = basicEnumFeignService.getEnumName(Integer.valueOf(deliveryStorageNotice.getQualityStandard()));//运输方式
        row1.createCell(10, Cell.CELL_TYPE_STRING).setCellValue(ysfs);
        
        int currentLastRowIndex = 7;
        
        for (int i = 0; i < storeWareDetailList.size(); i++) {
        	if(i!=0){
        		currentLastRowIndex = currentLastRowIndex+1;
	         }
        	Row row2 = sheetX.getRow(currentLastRowIndex);
        	 String  grainKind = basicEnumFeignService.getEnumName(Integer.valueOf(storeWareDetailList.get(i).getGrainKind()));
	         String  grainDetailKind = basicEnumFeignService.getEnumName(Integer.valueOf(storeWareDetailList.get(i).getGrainDetailKind()));
	         String  grainGrade = basicEnumFeignService.getEnumName(Integer.valueOf(storeWareDetailList.get(i).getGrainGrade()));
	         String  grainAttribute = basicEnumFeignService.getEnumName(Integer.valueOf(storeWareDetailList.get(i).getGrainAttribute()));
	         
			//row2.createCell(0, Cell.CELL_TYPE_STRING).setCellValue(i+1);
	       //根据orgId获取orgName
			String  orgName = orgFeignService.getOrgName(storeWareDetailList.get(i).getState());
			Cell cell11= row2.createCell(0);
	        cell11.setCellValue(orgName);
	        CellStyle style11= workbook.createCellStyle();
	        style11.setBorderLeft(CellStyle.BORDER_THIN);//左边框
	        style11.setAlignment(CellStyle.ALIGN_LEFT);//居左
	        cell11.setCellStyle(style11);
	        
			
			//row2.createCell(0, Cell.CELL_TYPE_STRING).setCellValue(orgName);
			row2.createCell(2, Cell.CELL_TYPE_STRING).setCellValue(storeWareDetailList.get(i).getHouseName());
			row2.createCell(3, Cell.CELL_TYPE_STRING).setCellValue(storeWareDetailList.get(i).getWarehouseName());
			row2.createCell(4, Cell.CELL_TYPE_STRING).setCellValue(grainKind);
			row2.createCell(5, Cell.CELL_TYPE_STRING).setCellValue(grainDetailKind);
			row2.createCell(6, Cell.CELL_TYPE_STRING).setCellValue(grainAttribute);
			row2.createCell(7, Cell.CELL_TYPE_STRING).setCellValue(grainGrade);
			if(deliveryStorageNotice.getBillType().equals("1")){//入库
				row2.createCell(8, Cell.CELL_TYPE_STRING).setCellValue(storeWareDetailList.get(i).getInCount());
				if(storeWareDetailList.get(i).getPlanRemainingNumber()!=null){
					row2.createCell(9, Cell.CELL_TYPE_STRING).setCellValue(storeWareDetailList.get(i).getPlanRemainingNumber());
				}
				if(storeWareDetailList.get(i).getPlanRemainingNumber()==null && storeWareDetailList.get(i).getRemainingNumber()!=null){
					row2.createCell(9, Cell.CELL_TYPE_STRING).setCellValue(storeWareDetailList.get(i).getRemainingNumber());
				}
				row2.createCell(10, Cell.CELL_TYPE_STRING).setCellValue(storeWareDetailList.get(i).getInPrice());
				//金额
				Cell cell4= row2.createCell(11);
		        cell4.setCellValue(storeWareDetailList.get(i).getInDetailTotalPrice());
		        CellStyle style4= workbook.createCellStyle();
		        style4.setBorderRight(CellStyle.BORDER_THIN);//右边框
		        cell4.setCellStyle(style4);
				//row2.createCell(11, Cell.CELL_TYPE_STRING).setCellValue(storeWareDetailList.get(i).getInDetailTotalPrice());
	         }else if(deliveryStorageNotice.getBillType().equals("3")){//出库
	        	row2.createCell(8, Cell.CELL_TYPE_STRING).setCellValue(storeWareDetailList.get(i).getOutCount());
	        	if(storeWareDetailList.get(i).getPlanOutRemainingNumber()!=null){
					row2.createCell(9, Cell.CELL_TYPE_STRING).setCellValue(storeWareDetailList.get(i).getPlanOutRemainingNumber());
				}
				if(storeWareDetailList.get(i).getPlanOutRemainingNumber()==null && storeWareDetailList.get(i).getOutRemainingNumber()!=null){
					row2.createCell(9, Cell.CELL_TYPE_STRING).setCellValue(storeWareDetailList.get(i).getOutRemainingNumber());
				}
			    row2.createCell(10, Cell.CELL_TYPE_STRING).setCellValue(storeWareDetailList.get(i).getOutPrice());
			   //金额
				Cell cell4= row2.createCell(11);
		        cell4.setCellValue(storeWareDetailList.get(i).getOutDetailTotalPrice());
		        CellStyle style4= workbook.createCellStyle();
		        style4.setBorderRight(CellStyle.BORDER_THIN);//右边框
		        cell4.setCellStyle(style4);
				//row2.createCell(11, Cell.CELL_TYPE_STRING).setCellValue(storeWareDetailList.get(i).getOutDetailTotalPrice());
	         }
		}
        //int currentLastRowIndex1 = sheetX.getLastRowNum() + 1;
        
        //总价
        Row row3 = sheetX.getRow(14);
        Cell cell4= row3.createCell(2);
        cell4.setCellValue(deliveryStorageNotice.getShipingCount());
        CellStyle style4= workbook.createCellStyle();
        style4.setBorderTop(CellStyle.BORDER_THIN);//上边框
        style4.setBorderBottom(CellStyle.BORDER_THIN);//下边框
        style4.setBorderRight(CellStyle.BORDER_THIN);//右边框
        style4.setBorderLeft(CellStyle.BORDER_THIN);//左边框
        cell4.setCellStyle(style4);
        Cell cell5= row3.createCell(9);
        cell5.setCellValue(deliveryStorageNotice.getMoneyQuantity());
        CellStyle style5= workbook.createCellStyle();
        style5.setBorderTop(CellStyle.BORDER_THIN);//上边框
        style5.setBorderBottom(CellStyle.BORDER_THIN);//下边框
        style5.setBorderRight(CellStyle.BORDER_THIN);//右边框
        style5.setBorderLeft(CellStyle.BORDER_THIN);//左边框
        cell5.setCellStyle(style5);
        
		//row3.createCell(2, Cell.CELL_TYPE_STRING).setCellValue(deliveryStorageNotice.getShipingCount());
		//row3.createCell(9, Cell.CELL_TYPE_STRING).setCellValue(deliveryStorageNotice.getMoneyQuantity());
		//客户信息
		Row row4 = sheetX.getRow(17);
		Cell cell6= row4.createCell(2);
        cell6.setCellValue(deliveryStorageNotice.getDeliveryCustomer());
        CellStyle style6= workbook.createCellStyle();
        style6.setBorderTop(CellStyle.BORDER_THIN);//上边框
        style6.setBorderBottom(CellStyle.BORDER_THIN);//下边框
        style6.setBorderRight(CellStyle.BORDER_THIN);//右边框
        cell6.setCellStyle(style6);
        
		//row4.createCell(2, Cell.CELL_TYPE_STRING).setCellValue(deliveryStorageNotice.getDeliveryCustomer());
		row4.createCell(7, Cell.CELL_TYPE_STRING).setCellValue(deliveryStorageNotice.getIdentification());
		Cell cell7= row4.createCell(11);
        cell7.setCellValue(deliveryStorageNotice.getMobile());
        CellStyle style7= workbook.createCellStyle();
        style7.setBorderRight(CellStyle.BORDER_THIN);//右边框
        cell7.setCellStyle(style7);
		
		//row4.createCell(11, Cell.CELL_TYPE_STRING).setCellValue(deliveryStorageNotice.getMobile());
		//备注
		Row row5 = sheetX.getRow(18);
		row5.createCell(2, Cell.CELL_TYPE_STRING).setCellValue(deliveryStorageNotice.getBillMemo());
		//创建信息
		Row row6 = sheetX.getRow(19);
		Cell cell8= row6.createCell(2);
        cell8.setCellValue(sf.format(deliveryStorageNotice.getBillDate()));
        CellStyle style8= workbook.createCellStyle();
        style8.setBorderTop(CellStyle.BORDER_THIN);//上边框
        style8.setBorderBottom(CellStyle.BORDER_THIN);//下边框
        style8.setBorderRight(CellStyle.BORDER_THIN);//右边框
        cell8.setCellStyle(style8);
        Cell cell9= row6.createCell(7);
        cell9.setCellValue(deliveryStorageNotice.getBillMan());
        CellStyle style9= workbook.createCellStyle();
        style9.setBorderTop(CellStyle.BORDER_THIN);//上边框
        style9.setBorderBottom(CellStyle.BORDER_THIN);//下边框
        style9.setBorderRight(CellStyle.BORDER_THIN);//右边框
        cell9.setCellStyle(style9);
		//row6.createCell(2, Cell.CELL_TYPE_STRING).setCellValue(sf.format(deliveryStorageNotice.getBillDate()));
		//row6.createCell(7, Cell.CELL_TYPE_STRING).setCellValue(deliveryStorageNotice.getBillMan());


        /*// ------ 创建一行新的数据 ----------//
        // 指定行索引，创建一行数据, 行索引为当前最后一行的行索引 + 1
        

        //获取仓房名称转换用数据
        Map<String,Object> basicEnumFeign = basicEnumFeignService.getStorehouseList(Integer.parseInt(orgId),"0");
        Map<Integer, Object> storehouseObj = (Map<Integer, Object>) basicEnumFeign.get("houseObj");
        for (DataKcglKcswDefault kcswData:listNumberTotal ) {
            int newRowIndex = currentLastRowIndex ++;
            Row newRow = sheetX.createRow(newRowIndex);

            // 开始创建并设置该行每一单元格的信息，该行单元格的索引从 0 开始
            int cellIndex = 0;

            // 创建一个单元格，设置其内的数据格式为字符串，并填充内容，其余单元格类同
            //仓房名称
            Cell cfmc = newRow.createCell(cellIndex++, Cell.CELL_TYPE_STRING);
            Map<String,String> houseData = (HashMap<String, String>) storehouseObj.get(kcswData.getCh().toString());
            cfmc.setCellValue(houseData.get("storehouseName"));
            Cell xm = newRow.createCell(cellIndex++, Cell.CELL_TYPE_STRING);
            //小麦
            if(ParameterUtil.isequal(kcswData.getPz(),"3164")){
                xm.setCellValue(kcswData.getKcsl());
            }else{
                xm.setCellValue("");
            }
            Cell dgxj = newRow.createCell(cellIndex++, Cell.CELL_TYPE_STRING);
            dgxj.setCellValue("");
            Cell zwxd = newRow.createCell(cellIndex++, Cell.CELL_TYPE_STRING);
            //中晚籼稻
            if(ParameterUtil.isequal(kcswData.getPz(),"3218") || ParameterUtil.isequal(kcswData.getPz(),"3219")){
                zwxd.setCellValue(kcswData.getKcsl());
            }else{
                zwxd.setCellValue("");
            }
            Cell jd = newRow.createCell(cellIndex++, Cell.CELL_TYPE_STRING);
            //粳稻
            if(ParameterUtil.isequal(kcswData.getPz(),"3220") || ParameterUtil.isequal(kcswData.getPz(),"3221")){
                jd.setCellValue(kcswData.getKcsl());
            }else{
                jd.setCellValue("");
            }
            Cell ym = newRow.createCell(cellIndex++, Cell.CELL_TYPE_STRING);
            //玉米
            if(ParameterUtil.isequal(kcswData.getPz(),"3165")){
                ym.setCellValue(kcswData.getKcsl());
            }else{
                ym.setCellValue("");
            }
        }*/
    }
}

